==> merchant-base-0.5.1-RELEASE-sources.jar: com/rocogz/merchant/dto/scm/UpOrderQueryDto.java <==
package com.rocogz.merchant.dto.scm;

import lombok.Data;
import lombok.experimental.Accessors;

import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * <dl>
 * <dd>Description: </dd>
 * <dd>Company: 大诚若谷信息技术有限公司</dd>
 * <dd>@date：2021/3/12 17:01</dd>
 * <dd>@author：ranxiangfu</dd>
 * </dl>
 */
@Data
@Accessors(chain = true)
public class UpOrderQueryDto {
    /**
     * 上游订单编号
     */
    private String orderItemCode;
    /**
     * 下游订单编号
     */
    private String orderCode;
    /**
     * 合作客户产品编号
     */
    private String customerProductCode;
    /**
     * 合作客户产品名称
     */
    private String customerProductName;
    /**
     * 代理商产品编号
     */
    private String agentProductCode;
    /**
     * 代理商产品名称
     */
    private String agentProductName ;
    /**
     * 平台产品编号
     */
    private String productCode;
    /**
     * 平台产品名称
     */
    private String productName;
    /**
     * 产品类别
     */
    private String productCategoryCode;
    /**
     * 产品分类
     */
    private String productTypeCode;
    private String productTypeName;
    /**
     * 产品性质
     */
    private String goodsNature;
    /**
     * 第三方产品编码
     */
    private String thirdProductCode;
    /**
     * 发放会员手机号
     */
    private String grantMobile;
    /**
     * 发放会员证件类型
     */
    private String grantIdtype;
    /**
     * 发放会员证件信息
     */
    private String grantIdno;
    /**
     * 发放会员车牌号
     */
    private String grantLicence;
    /**
     * 发放会员姓名
     */
    private String grantUsername;
    /**
     * 发放会员保单号
     */
    private String policyNumber;
    /**
     * 真实会员手机号
     */
    private String realMobile;
    /**
     * 第三方业务状态
     */
    private String thirdBusinessStatus;
    /**
     * 第三方业务号
     */
    private String thirdBusinessCode;
    /**
     * ROCO车服用户券号
     */
    private String rocoUserCouponCode;
    /**
     * 发放张数
     */
    private String grantNum;
    /**
     * 订单价格
     */
    private String detailPrice;

    /**
     * 领取状态
     */
    private String receiveValidateStatus;

    /**
     * 领取开始时间
     */
    private String receiveValidateTimeStart;
    /**
     * 领取结束时间
     */
    private String receiveValidateTimeEnd;
    /**
     * 发放性质（正常发券，业务验证)
     */
    private String grantNature;
    /**
     * 下单业务号
     */
    private String businessCode;

    /**
     * 发放主体
     */
    private String sourceCode;
    /**
     * 发放客户代理商
     */
    private String sourceCustomerAgent;

    /**
     * 发放客户合作客户 数据库的字段对应的都是sourceCustomer
     */
    private String sourceCustomer;


    /**
     * 备付金退款状态
     */
    private String coverRefundStatus;

    /**
     * 备付金支付状态
     */
    private String coverPayStatus;
    /**
     * 支付时间开始
     */
    private String coverPayTimeStart;
    /**
     * 支付时间结束
     */
    private String coverPayTimeEnd;

    /**
     * 备付金退款时间开始
     */
    private String coverRefundTimeStart;

    /**
     * 备付金退款时间结束
     */
    private String coverRefundTimeEnd;

    /**
     * 备付金撤回时间开始
     */
    private String coverRecallTimeStart;

    /**
     * 备付金撤回时间结束
     */
    private String coverRecallTimeEnd;

    /**
     * 订单类型
     */
    private String orderType;


    /**
     * 发放目标平台（投放平台)
     */
    private String targetMiniAppid;


    private LocalDateTime orderTimeStart;
    private LocalDateTime orderTimeEnd;
    private LocalDateTime grantTimeStart;
    private LocalDateTime grantTimeEnd;

    /**
     * 发放成功开始时间
     */
    private String thirdGrantSuccessTimeStart;
    /**
     * 发放成功结束时间
     */
    private String thirdGrantSuccessTimeEnd;

    /**
     * 通道产品编号
     */
    private String channelProductCode;

    /**
     * 通道产品-第三方平台编码
     */
    private String channelProductPlatformCode;


    /**
     * 通道产品-扣款主体编号
     */
    private String channelProductDeductSubjectCode;



    private String writeOffStatus;
    private String orderStatus;
    private String orderItemStatus;
    private Boolean export = false;
    private Integer page = 1;
    private Integer limit = 10;
}

==> merchant-base-0.5.32-RELEASE-sources.jar: com/rocogz/merchant/dto/scm/UpOrderQueryDto.java <==
package com.rocogz.merchant.dto.scm;

import com.rocogz.merchant.constant.Constant;
import lombok.Data;
import lombok.experimental.Accessors;

import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * <dl>
 * <dd>Description: </dd>
 * <dd>Company: 大诚若谷信息技术有限公司</dd>
 * <dd>@date：2021/3/12 17:01</dd>
 * <dd>@author：ranxiangfu</dd>
 * </dl>
 */
@Data
@Accessors(chain = true)
public class UpOrderQueryDto {

    /**
     * 是否只是查询过期的上游订单，领取有效期过期或使用有效期过期
     */
    private Boolean expired;

    /**
     * 上游订单编号
     */
    private String orderItemCode;
    /**
     * 下游订单编号
     */
    private String orderCode;
    /**
     * 合作客户产品编号
     */
    private String customerProductCode;
    /**
     * 合作客户产品名称
     */
    private String customerProductName;
    /**
     * 代理商产品编号
     */
    private String agentProductCode;
    /**
     * 代理商产品名称
     */
    private String agentProductName ;
    /**
     * 平台产品编号
     */
    private String productCode;
    /**
     * 平台产品名称
     */
    private String productName;
    /**
     * 产品类别
     */
    private String productCategoryCode;
    /**
     * 产品分类
     */
    private String productTypeCode;
    private String productTypeName;
    /**
     * 产品性质
     */
    private String goodsNature;
    /**
     * 第三方产品编码
     */
    private String thirdProductCode;
    /**
     * 发放会员手机号
     */
    private String grantMobile;
    /**
     * 发放会员证件类型
     */
    private String grantIdtype;
    /**
     * 发放会员证件信息
     */
    private String grantIdno;
    /**
     * 发放会员车牌号
     */
    private String grantLicence;
    /**
     * 发放会员姓名
     */
    private String grantUsername;

    /**
     * 发放会员车架号
     */
    private String vinNo;

    /**
     * 发放会员保单号
     */
    private String policyNumber;
    /**
     * 真实会员手机号
     */
    private String realMobile;
    /**
     * 第三方业务状态
     */
    private String thirdBusinessStatus;
    /**
     * 第三方业务号
     */
    private String thirdBusinessCode;
    /**
     * ROCO车服用户券号
     */
    private String rocoUserCouponCode;
    /**
     * 发放张数
     */
    private String grantNum;
    /**
     * 订单价格
     */
    private String detailPrice;

    /**
     * 领取状态
     */
    private String receiveValidateStatus;

    /**
     * 领取开始时间
     */
    private String receiveValidateTimeStart;
    /**
     * 领取结束时间
     */
    private String receiveValidateTimeEnd;
    /**
     * 发放性质（正常发券，业务验证)
     */
    private String grantNature;
    /**
     * 下单业务号
     */
    private String businessCode;

    /**
     * 发放主体
     */
    private String sourceCode;
    /**
     * 发放客户代理商
     */
    private String sourceCustomerAgent;

    /**
     * 发放客户合作客户 数据库的字段对应的都是sourceCustomer
     */
    private String sourceCustomer;


    /**
     * 备付金退款状态
     */
    private String coverRefundStatus;

    /**
     * 备付金支付状态
     */
    private String coverPayStatus;
    /**
     * 支付时间开始
     */
    private String coverPayTimeStart;
    /**
     * 支付时间结束
     */
    private String coverPayTimeEnd;

    /**
     * 备付金退款时间开始
     */
    private String coverRefundTimeStart;

    /**
     * 备付金退款时间结束
     */
    private String coverRefundTimeEnd;

    /**
     * 备付金撤回时间开始
     */
    private String coverRecallTimeStart;

    /**
     * 备付金撤回时间结束
     */
    private String coverRecallTimeEnd;

    /**
     * 订单类型
     */
    private String orderType;

    /**
     * 使用状态
     * @see Constant.DictUseStatus
     */
    private String useStatus;


    /**
     * 发放目标平台（投放平台)
     */
    private String targetMiniAppid;


    private LocalDateTime orderTimeStart;
    private LocalDateTime orderTimeEnd;
    private LocalDateTime grantTimeStart;
    private LocalDateTime grantTimeEnd;

    /**
     * 发放成功开始时间
     */
    private String thirdGrantSuccessTimeStart;
    /**
     * 发放成功结束时间
     */
    private String thirdGrantSuccessTimeEnd;

    /**
     * 通道产品编号
     */
    private String channelProductCode;

    /**
     * 通道产品-第三方平台编码
     */
    private String channelProductPlatformCode;


    /**
     * 通道产品-扣款主体编号
     */
    private String channelProductDeductSubjectCode;



    private String writeOffStatus;
    private String orderStatus;
    private String orderItemStatus;
    private Boolean export = false;
    private Integer page = 1;
    private Integer limit = 10;
}
